==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/MoonRabbitEntity.java <==
package cc.thonly.reverie_dreams.entity;

import cc.thonly.reverie_dreams.entity.ai.goal.UniversalLivingAngerGoal;
import net.minecraft.class_1266;
import net.minecraft.class_1296;
import net.minecraft.class_1299;
import net.minecraft.class_1315;
import net.minecraft.class_1324;
import net.minecraft.class_1341;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1366;
import net.minecraft.class_1391;
import net.minecraft.class_1394;
import net.minecraft.class_1399;
import net.minecraft.class_1463;
import net.minecraft.class_1493;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2945;
import net.minecraft.class_3218;
import net.minecraft.class_3489;
import net.minecraft.class_3730;
import net.minecraft.class_5131;
import net.minecraft.class_5134;
import net.minecraft.class_5425;
import net.minecraft.class_6868;
import net.minecraft.entity.ai.goal.*;
import org.jetbrains.annotations.Nullable;

public class MoonRabbitEntity extends class_1463 {
    public MoonRabbitEntity(class_1299<? extends class_1463> entityType, class_1937 world) {
        super(entityType, world);
        this.method_47853(class_7990.field_41562);
        class_5131 attributeContainer = this.method_6127();
        if (attributeContainer != null) {
            class_1324 scale = attributeContainer.method_45329(class_5134.field_47760);
            if (scale != null) {
                scale.method_6192(1.8);
            }
        }
    }

    public MoonRabbitEntity(class_1937 world) {
        this(ModEntities.MOON_RABBIT_ENTITY_TYPE, world);
    }

    @Override
    public @Nullable class_1315 method_5943(class_5425 world, class_1266 difficulty, class_3730 spawnReason, @Nullable class_1315 entityData) {
        class_1315 data = super.method_5943(world, difficulty, spawnReason, entityData);
        this.method_47853(class_7990.field_41562);
        return data;
    }

    @Override
    protected void method_5959() {
        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new class_6868(this, this.method_37908()));
//        this.goalSelector.add(1, new EscapeDangerGoal(this, 2.2));
        this.field_6201.method_6277(2, new class_1341(this, 0.8));
        this.field_6201.method_6277(2, new class_1366(this, 1.2, true));
        this.field_6201.method_6277(3, new class_1391(this, 1.0, stack -> stack.method_31573(class_3489.field_49951), false));
//        this.goalSelector.add(4, new FleeGoal<PlayerEntity>(this, PlayerEntity.class, 8.0f, 2.2, 2.2));
        this.field_6201.method_6277(4, new class_1465<class_1493>(this, class_1493.class, 10.0f, 2.2, 2.2));
//        this.goalSelector.add(4, new FleeGoal<HostileEntity>(this, HostileEntity.class, 4.0f, 2.2, 2.2));
        this.field_6201.method_6277(5, new class_1470(this));
        this.field_6201.method_6277(6, new class_1394(this, 0.6));
        this.field_6201.method_6277(11, new class_1361(this, class_1657.class, 10.0f));

        this.field_6185.method_6277(3, new class_1399(this));
        this.field_6185.method_6277(3, new UniversalLivingAngerGoal<>(this, false));

    }

    @Override
    protected void method_5693(class_2945.class_9222 builder) {
        super.method_5693(builder);
    }



    @Override
    public class_7990 method_47855() {
        return class_7990.field_41562;
    }

    @Override
    public @Nullable class_1463 method_6620(class_3218 serverWorld, class_1296 passiveEntity) {
        return ModEntities.MOON_RABBIT_ENTITY_TYPE.method_5883(serverWorld, class_3730.field_16466);
    }

}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/MoonRabbitEntity.java <==
package cc.thonly.reverie_dreams.entity;

import cc.thonly.reverie_dreams.entity.ai.goal.UniversalLivingAngerGoal;
import cc.thonly.reverie_dreams.registry.content.entity.RDEntityTypes;
import net.minecraft.class_1266;
import net.minecraft.class_1296;
import net.minecraft.class_1299;
import net.minecraft.class_1315;
import net.minecraft.class_1324;
import net.minecraft.class_1341;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1366;
import net.minecraft.class_1391;
import net.minecraft.class_1394;
import net.minecraft.class_1399;
import net.minecraft.class_1463;
import net.minecraft.class_1493;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2945;
import net.minecraft.class_3218;
import net.minecraft.class_3489;
import net.minecraft.class_3730;
import net.minecraft.class_5131;
import net.minecraft.class_5134;
import net.minecraft.class_5425;
import net.minecraft.class_6868;
import org.jetbrains.annotations.Nullable;

public class MoonRabbitEntity extends class_1463 {
    public MoonRabbitEntity(class_1299<? extends class_1463> entityType, class_1937 world) {
        super(entityType, world);
        this.method_47853(class_7990.field_41562);
        class_5131 attributeContainer = this.method_6127();
        if (attributeContainer != null) {
            class_1324 scale = attributeContainer.method_45329(class_5134.field_47760);
            if (scale != null) {
                scale.method_6192(1.8);
            }
        }
    }

    public MoonRabbitEntity(class_1937 world) {
        this(RDEntityTypes.MOON_RABBIT_ENTITY_TYPE, world);
    }

    @Override
    public @Nullable class_1315 method_5943(class_5425 world, class_1266 difficulty, class_3730 spawnReason, @Nullable class_1315 entityData) {
        class_1315 data = super.method_5943(world, difficulty, spawnReason, entityData);
        this.method_47853(class_7990.field_41562);
        return data;
    }

    @Override
    protected void method_5959() {
        this.field_6201.method_6277(0, new class_1347(this));
        this.field_6201.method_6277(1, new class_6868(this, this.method_37908()));
//        this.goalSelector.add(1, new EscapeDangerGoal(this, 2.2));
        this.field_6201.method_6277(2, new class_1341(this, 0.8));
        this.field_6201.method_6277(2, new class_1366(this, 1.2, true));
        this.field_6201.method_6277(3, new class_1391(this, 1.0, stack -> stack.method_31573(class_3489.field_49951), false));
//        this.goalSelector.add(4, new FleeGoal<PlayerEntity>(this, PlayerEntity.class, 8.0f, 2.2, 2.2));
        this.field_6201.method_6277(4, new class_1465<class_1493>(this, class_1493.class, 10.0f, 2.2, 2.2));
//        this.goalSelector.add(4, new FleeGoal<HostileEntity>(this, HostileEntity.class, 4.0f, 2.2, 2.2));
        this.field_6201.method_6277(5, new class_1470(this));
        this.field_6201.method_6277(6, new class_1394(this, 0.6));
        this.field_6201.method_6277(11, new class_1361(this, class_1657.class, 10.0f));

        this.field_6185.method_6277(3, new class_1399(this));
        this.field_6185.method_6277(3, new UniversalLivingAngerGoal<>(this, false));

    }

    @Override
    protected void method_5693(class_2945.class_9222 builder) {
        super.method_5693(builder);
    }



    @Override
    public class_7990 method_47855() {
        return class_7990.field_41562;
    }

    @Override
    public @Nullable class_1463 method_5613(class_3218 serverWorld, class_1296 passiveEntity) {
        return RDEntityTypes.MOON_RABBIT_ENTITY_TYPE.method_5883(serverWorld, class_3730.field_16466);
    }

}
